@@ -6,8 +6,8 @@ class StructureManager(object):
 
     folder_struct = dict(
         root_folder_path = os.path.join('liquidcss_'),
-        css_folder_path = os.path.join('liquidcss_', 'css'),
-        html_folder_path = os.path.join('liquidcss_', 'html'),
+        css = os.path.join('liquidcss_', 'css'),
+        html = os.path.join('liquidcss_', 'html'),
     )
 
 
@@ -23,8 +23,8 @@ class StructureManager(object):
             )
         )
 
-
-    def _validate_structure(self):
+    @property
+    def _missing_key(self):
         for key, value in StructureManager.folder_struct.items():
             if os.path.isdir(os.path.join(self.base_dir, value)):
                 continue
@@ -32,11 +32,17 @@ class StructureManager(object):
                 return key
 
 
-    def create_structure(self):
-        missing_key = self._validate_structure()
+    def create_file(self, type_, file_name, string):
+        path = os.path.join(self.base_dir, StructureManager.folder_struct[type_], file_name)
+        with open(path, 'w') as file:
+            file.write(string.decode('ascii'))
+
+
+    def validate_structure(self):
+        missing_key = self._missing_key
         if missing_key:
             self._create_folder(folder_struct_key = missing_key)
-            self.create_structure()
+            self.validate_structure()
         else:
             return True
             
